package XML::CompareML;
$XML::CompareML::VERSION = '0.2.13';
use strict;
use warnings;

use 5.008;

1;    # End of XML::CompareML

__END__

=pod

=encoding UTF-8

=head1 NAME

XML::CompareML - A processor for the CompareML markup language

=head1 VERSION

version 0.2.13

=head1 SYNOPSIS

    use XML::CompareML::HTML;

    my $converter =
        XML::CompareML::HTML->new(
            'input_filename' => "my-comparison.xml",
            'output_handle' => \*STDOUT,
        );

    $converter->process();

Or alternatively:

    use XML::CompareML::DocBook;

    my $converter =
        XML::CompareML::DocBook->new(
            'input_filename' => "my-comparison.xml",
            'output_handle' => \*STDOUT,
        );

    $converter->process();

=head1 USAGE

The CompareML language is currently undocumented, but one can see
an example for a document written it in the
C<t/files/scm-comparison.xml> example in the distribution.

To convert a CompareML document to HTML instantiate an XML::CompareML::HTML
object, and pass it the filename as the C<input_filename> named parameter,
and a reference to the IO handle to output the result as the C<output_handle>
named parameter.

To convert a CompareML document to DocBook do the same procedure only using
an XML:CompareML::DocBook object.

=head1 AUTHOR

Shlomi Fish, L<http://www.shlomifish.org/> .

=head1 BUGS

Please report any bugs or feature requests to
C<bug-xml-compareml@rt.cpan.org>, or through the web interface at
L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=XML::CompareML>.
I will be notified, and then you'll automatically be notified of progress on
your bug as I make changes.

=head1 ACKNOWLEDGEMENTS

=head1 COPYRIGHT & LICENSE

Copyright 2005 Shlomi Fish, All Rights Reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as the MIT / Expat license.

=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan

=head1 SUPPORT

=head2 Websites

The following websites have more information about this module, and may be of help to you. As always,
in addition to those websites please use your favorite search engine to discover more resources.

=over 4

=item *

MetaCPAN

A modern, open-source CPAN search engine, useful to view POD in HTML format.

L<https://metacpan.org/release/XML-CompareML>

=item *

RT: CPAN's Bug Tracker

The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.

L<https://rt.cpan.org/Public/Dist/Display.html?Name=XML-CompareML>

=item *

CPANTS

The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.

L<http://cpants.cpanauthors.org/dist/XML-CompareML>

=item *

CPAN Testers

The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.

L<http://www.cpantesters.org/distro/X/XML-CompareML>

=item *

CPAN Testers Matrix

The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.

L<http://matrix.cpantesters.org/?dist=XML-CompareML>

=item *

CPAN Testers Dependencies

The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.

L<http://deps.cpantesters.org/?module=XML::CompareML>

=back

=head2 Bugs / Feature Requests

Please report any bugs or feature requests by email to C<bug-xml-compareml at rt.cpan.org>, or through
the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=XML-CompareML>. You will be automatically notified of any
progress on the request by the system.

=head2 Source Code

The code is open to the world, and available for you to hack on. Please feel free to browse it and play
with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
from your repository :)

L<https://github.com/shlomif/xml-compareml>

  git clone git://github.com/shlomif/xml-compareml.git

=head1 AUTHOR

Shlomi Fish <shlomif@cpan.org>

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website
L<https://github.com/shlomif/xml-compareml/issues>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018 by Shlomi Fish.

This is free software, licensed under:

  The MIT (X11) License

=cut
